Index: base/android/sys_utils_unittest.cc |
diff --git a/base/android/sys_utils_unittest.cc b/base/android/sys_utils_unittest.cc |
index 2a5a17d8532c363fa7fb1f61871d1133cabb3fd1..fc0282ad713c310fd273f322d3ebca9c754cf904 100644 |
--- a/base/android/sys_utils_unittest.cc |
+++ b/base/android/sys_utils_unittest.cc |
@@ -2,10 +2,9 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#include "base/android/sys_utils.h" |
- |
#include <unistd.h> |
+#include "base/sys_info.h" |
#include "testing/gtest/include/gtest/gtest.h" |
namespace base { |
@@ -13,10 +12,10 @@ namespace android { |
TEST(SysUtils, AmountOfPhysicalMemory) { |
// Check that the RAM size reported by sysconf() matches the one |
// computed by base::android::SysUtils::AmountOfPhysicalMemory(). |
size_t sys_ram_size = |
static_cast<size_t>(sysconf(_SC_PHYS_PAGES) * PAGE_SIZE); |
- EXPECT_EQ(sys_ram_size, SysUtils::AmountOfPhysicalMemoryKB() * 1024UL); |
+ EXPECT_EQ(sys_ram_size, SysInfo::AmountOfPhysicalMemory()); |
} |
} // namespace android |
@@ -13,10 +12,10 @@ namespace android { |
TEST(SysUtils, AmountOfPhysicalMemory) { |
// Check that the RAM size reported by sysconf() matches the one |
- // computed by base::android::SysUtils::AmountOfPhysicalMemory(). |
+ // computed by base::SysInfo::AmountOfPhysicalMemory(). |
size_t sys_ram_size = |
static_cast<size_t>(sysconf(_SC_PHYS_PAGES) * PAGE_SIZE); |